
BEGIN
/* Complex scheduling example 1: Public Holidays */
DBMS_SCHEDULER.CREATE_SCHEDULE
(schedule_name => 'SCHEDULE3'
,start_date => to_timestamp_tz('01/01/2015 00:00:00','dd/mm/yyyy hh24:mi:ss')
,end_date => to_timestamp_tz('31/12/2015 23:59:59','dd/mm/yyyy hh24:mi:ss')
,repeat_interval =>'freq=YEARLY;bydate=20150607,20150608,20150701'
,comments => 'Public Holidays 2015'
);
END;

BEGIN
/* Complex scheduling example 2: Working Days */
DBMS_SCHEDULER.CREATE_SCHEDULE
(schedule_name => 'SCHEDULE31'
,start_date => to_timestamp_tz('01/01/2015 00:00:00','dd/mm/yyyy hh24:mi:ss')
,end_date => to_timestamp_tz('31/12/2015 23:59:59','dd/mm/yyyy hh24:mi:ss')
,repeat_interval =>
'freq=YEARLY;byday=MON,TUE,WED,THU,FRI;'
,comments => 'Run on every working day'
);
END;
/

----

declare
   v_1  timestamp;
begin
  for i in 1..1
   loop
    DBMS_SCHEDULER.EVALUATE_CALENDAR_STRING (    calendar_string=>'FREQ=yearly;bydate=20150607,20150608,20150701;BYHOUR=14;BYMINUTE=10;BYSECOND=0;exclude=HR.SCHEDULE31'   ,
   start_date => sysdate,
   return_date_after  => v_1,
   next_run_date    => v_1 );
  dbms_output.put_line(to_char(v_1,'YYYY-MM-DD:HH24:MI:SS'));
end loop;
end;

declare
   v_1  timestamp;
begin
  for i in 1..1
   loop
    DBMS_SCHEDULER.EVALUATE_CALENDAR_STRING (    calendar_string=>'FREQ=yearly;bydate=20150607,20150608,20150701;BYHOUR=14;BYMINUTE=10;BYSECOND=0;include=HR.SCHEDULE31'   ,
   start_date => sysdate,
   return_date_after  => v_1,
   next_run_date    => v_1 );
  dbms_output.put_line(to_char(v_1,'YYYY-MM-DD:HH24:MI:SS'));
end loop;
end;

declare
   v_1  timestamp;
begin
  for i in 1..1
   loop
    DBMS_SCHEDULER.EVALUATE_CALENDAR_STRING (    calendar_string=>'FREQ=yearly;bydate=20150607,20150608,20150701;BYHOUR=14;BYMINUTE=10;BYSECOND=0;intersect=HR.SCHEDULE31'   ,
   start_date => sysdate,
   return_date_after  => v_1,
   next_run_date    => v_1 );
  dbms_output.put_line(to_char(v_1,'YYYY-MM-DD:HH24:MI:SS'));
end loop;
end;

--HR.SCHEDULE31 should has no hour, no minute and no second specifications.
 
'FREQ=YEARLY;BYYEARDAY=1,32,-306'
The following example creates a schedule consisting of the first working day of every month in 2008:
'freq=MONTHLY;byday=MON,TUE,WED,THU,FRI;bysetpos=1'
1st and 3rd Monday each month:
'freq=MONTHLY;byday=1MON,3MON'
The following example creates a schedule consisting of the last day of each quarter:
'freq=YEARLY;bymonth=MAR,JUN,SEP,DEC;bymonthday=-1'
